/*

File IKfunctions.h

Release 1.2, 7 June 1994
Copyright (C) 1994 by H. Scott Roy

This code is part of IconKit, a general toolbox for drag-and-drop applications.  IconKit is free for noncommercial use, but costs money for a commercial license.  You should have received a copy of the license agreement with this file.  If not, a copy of the license and the complete source of IconKit can be obtained from the author:

		H. Scott Roy
		2573 Stowe Ct.
		Northbrook, IL  60062-8103
		iconkit@cs.stanford.edu

For your editing convenience, this file is best viewed using an editor that automatically wraps long lines, in a fixed point font at 80 columns, with tabs every 4 spaces.

*/


/* ========================================================================== */


/*

This file contains miscellaneous functions that support the IconKit.  Currently it contains functions that support copy and paste through local id, as well as a debugging function, runtime conformance checks, and a function to shorten the title of a cell to fit within its bounds.

*/

#import <appkit/Pasteboard.h>


/* ========================================================================== */


/*

An IKIconObject must be able to write itself to a pasteboard, and its class must be able to read back instances from the pasteboard.  The IconKit provides a simple way to do this using an object's id.  Such dragging works only within a single application, so programmers will need to set up a more elaborate mechanism for interapplication dragging.  The FileViewer example gives a good illustration.

	-WARNING-

The IKidPboardType is globally available to mimic the way one uses the standard pasteboard types.  However, it must get initialized to a random string (very important) before being used.  Calls to IKInitIDpboardType() are scattered about the IconKit in all the class initialization methods, so you should be safe.  But if you somehow manage to bypass them all, be sure to call IKInitIDpboardType() yourself.

*/

extern NXAtom		IKidPboardType;

extern void			IKInitIDpboardType (void);
extern void			IKCopyID (Pasteboard * pboard, id object);
extern id			IKReadID (Pasteboard * pboard);
extern NXAtom	  * IKIDPasteTypes (void);

extern void			IKdprintf (const char * format, ...);
extern void			IKSetDebug (BOOL flag);
extern BOOL			IKCheckConformance (id object);
extern void			IKShortenTitle (Cell * text,  float maxWidth);
