/*

File IKBrowserInspector.m

Release 1.2, 7 June 1994
Copyright (C) 1994 by H. Scott Roy

This code is part of IconKit, a general toolbox for drag-and-drop applications.  IconKit is free for noncommercial use, but costs money for a commercial license.  You should have received a copy of the license agreement with this file.  If not, a copy of the license and the complete source of IconKit can be obtained from the author:

		H. Scott Roy
		2573 Stowe Ct.
		Northbrook, IL  60062-8103
		iconkit@cs.stanford.edu

For your editing convenience, this file is best viewed using an editor that automatically wraps long lines, in a fixed point font at 80 columns, with tabs every 4 spaces.

*/


/* ========================================================================== */


/*

This file implements a custom inspector for an IKBrowser.  The inspector gets rid of most of the options for a standard browser (they're normally inappropriate for an IKBrowser), and puts in controls to set up the number of columns that the browser displays.

*/

#import "IKBrowserInspector.h"
#import "IKBrowser.h"

@implementation IKBrowserInspector


/* ========================================================================== */


#define COLUMNS			0
#define MAXVISIBLE		1
#define MINWIDTH		2


/* ========================================================================== */


- init
{
    char	path [MAXPATHLEN + 1];
    id		bundle;
    
    [super init];
    
    bundle = [NXBundle  bundleForClass: [IKBrowser class]];
    [bundle  getPath: path  forResource: "IKBrowserInspector"  ofType: "nib"];
    [NXApp  loadNibFile: path  owner: self  withNames: NO
				fromZone: [self zone]];
    
	return self;
}


/* ========================================================================== */


/*

All three options are reset whenever the user changes one of them.

*/

- ok: sender
{
	[[[[object
			setMinColumnWidth: 1]
			setMaxVisibleColumns: [[form  findCellWithTag: COLUMNS]  intValue]]
			setMinColumnWidth: [[form  findCellWithTag: MINWIDTH]  intValue]]
			setMaxVisibleColumns: [[form  findCellWithTag: MAXVISIBLE]
					intValue]];
	
    return [super ok: sender];
}


- revert: sender
{
	[[form findCellWithTag: COLUMNS]  setIntValue: [object  numVisibleColumns]];
	[[form findCellWithTag: MINWIDTH]  setIntValue: [object  minColumnWidth]];
	[[form findCellWithTag: MAXVISIBLE]  setIntValue: [object
				maxVisibleColumns]];
	
    return [super revert: sender];
}


- (BOOL) wantsButtons
{
    return NO;
}


@end
